Enum EcsAccessLevel
pub enum EcsAccessLevel {
Read(ComponentId),
Write(ComponentId),
ReadAll,
WriteAll,
}Expand description
The way the data will be accessed and whether we take access on all the components on an entity or just one component.
Variants
Read(ComponentId)
Reads Component with ComponentId
Write(ComponentId)
Writes Component with ComponentId
ReadAll
WriteAll