Enum QueryEntityError
pub enum QueryEntityError {
QueryDoesNotMatch(Entity, ArchetypeId),
NotSpawned(EntityNotSpawnedError),
AliasedMutability(Entity),
}Expand description
An error that occurs when retrieving a specific Entity’s query result from Query or QueryState.
Variants
QueryDoesNotMatch(Entity, ArchetypeId)
The given Entity’s components do not match the query.
Either it does not have a requested component, or it has a component which the query filters out.
NotSpawned(EntityNotSpawnedError)
The given Entity is not spawned.
AliasedMutability(Entity)
The Entity was requested mutably more than once.
See Query::get_many_mut for an example.