Struct AccessFilters
pub struct AccessFilters { /* private fields */ }Expand description
A clause in disjunctive normal form that filters entities by their components.
An AccessFilters matches entities that have all the components in the
with filters and none of the components in the without filters.
Implementations
impl AccessFilters
impl AccessFilters
pub fn with(&self) -> &ComponentIdSet
pub fn with(&self) -> &ComponentIdSet
The set of components that must all be present for this AccessFilters to match.
pub fn without(&self) -> &ComponentIdSet
pub fn without(&self) -> &ComponentIdSet
The set of components that must all be absent for this AccessFilters to match.