Struct Has
pub struct Has<T>(/* private fields */);Expand description
Returns a bool that describes if an entity has the component T.
This can be used in a Query if you want to know whether or not entities
have the component T but don’t actually care about the component’s value.
Footguns
Note that a Query<Has<T>> will match all existing entities.
Beware! Even if it matches all entities, it doesn’t mean that query.get(entity)
will always return Ok(bool).
In the case of a non-existent entity, such as a despawned one, it will return Err.
A workaround is to replace query.get(entity).unwrap() by
query.get(entity).unwrap_or_default().
Examples
fn food_entity_system(query: Query<(&Name, Has<IsHungry>) >) {
for (name, is_hungry) in &query {
if is_hungry{
println!("{} would like some food.", name.name);
} else {
println!("{} has had sufficient.", name.name);
}
}
}// Unlike `Option<&T>`, `Has<T>` is compatible with `&mut T`
// as it does not actually access any data.
fn alphabet_entity_system(mut alphas: Query<(&mut Alpha, Has<Beta>)>, mut betas: Query<(&mut Beta, Has<Alpha>)>) {
for (mut alpha, has_beta) in alphas.iter_mut() {
alpha.has_beta = has_beta;
}
for (mut beta, has_alpha) in betas.iter_mut() {
beta.has_alpha = has_alpha;
}
}Trait Implementations
impl<T> ContiguousQueryData for Has<T>where
T: Component,
impl<T> ContiguousQueryData for Has<T>where
T: Component,
type Contiguous<'w, 's> = bool
type Contiguous<'w, 's> = bool
Item returned by
ContiguousQueryData::fetch_contiguous.
Represents a contiguous chunk of memory.unsafe fn fetch_contiguous<'w, 's>(
_state: &'s <Has<T> as WorldQuery>::State,
fetch: &mut <Has<T> as WorldQuery>::Fetch<'w>,
_entities: &'w [Entity],
) -> <Has<T> as ContiguousQueryData>::Contiguous<'w, 's>
unsafe fn fetch_contiguous<'w, 's>( _state: &'s <Has<T> as WorldQuery>::State, fetch: &mut <Has<T> as WorldQuery>::Fetch<'w>, _entities: &'w [Entity], ) -> <Has<T> as ContiguousQueryData>::Contiguous<'w, 's>
Fetch
ContiguousQueryData::Contiguous which represents a contiguous chunk of memory (e.g., an array) in the current Table.
This must always be called after WorldQuery::set_table. Read moreimpl<T> QueryData for Has<T>where
T: Component,
impl<T> QueryData for Has<T>where
T: Component,
const IS_READ_ONLY: bool = true
const IS_READ_ONLY: bool = true
True if this query is read-only and may not perform mutable access.
const IS_ARCHETYPAL: bool = true
const IS_ARCHETYPAL: bool = true
Returns true if (and only if) this query data relies strictly on archetypes to limit which
entities are accessed by the Query. Read more
type ReadOnly = Has<T>
type ReadOnly = Has<T>
The read-only variant of this
QueryData, which satisfies the ReadOnlyQueryData trait.type Item<'w, 's> = bool
type Item<'w, 's> = bool
The item returned by this
WorldQuery
This will be the data retrieved by the query,
and is visible to the end user when calling e.g. Query<Self>::get.fn shrink<'wlong, 'wshort, 's>(
item: <Has<T> as QueryData>::Item<'wlong, 's>,
) -> <Has<T> as QueryData>::Item<'wshort, 's>where
'wlong: 'wshort,
fn shrink<'wlong, 'wshort, 's>(
item: <Has<T> as QueryData>::Item<'wlong, 's>,
) -> <Has<T> as QueryData>::Item<'wshort, 's>where
'wlong: 'wshort,
This function manually implements subtyping for the query items.
unsafe fn fetch<'w, 's>(
_state: &'s <Has<T> as WorldQuery>::State,
fetch: &mut <Has<T> as WorldQuery>::Fetch<'w>,
_entity: Entity,
_table_row: TableRow,
) -> Option<<Has<T> as QueryData>::Item<'w, 's>>
unsafe fn fetch<'w, 's>( _state: &'s <Has<T> as WorldQuery>::State, fetch: &mut <Has<T> as WorldQuery>::Fetch<'w>, _entity: Entity, _table_row: TableRow, ) -> Option<<Has<T> as QueryData>::Item<'w, 's>>
Fetch
Self::Item for either the given entity in the current Table,
or for the given entity in the current Archetype. This must always be called after
WorldQuery::set_table with a table_row in the range of the current Table or after
WorldQuery::set_archetype with an entity in the current archetype.
Accesses components registered in WorldQuery::update_component_access. Read morefn iter_access(
_state: &<Has<T> as WorldQuery>::State,
) -> impl Iterator<Item = EcsAccessType<'_>>
fn iter_access( _state: &<Has<T> as WorldQuery>::State, ) -> impl Iterator<Item = EcsAccessType<'_>>
Returns an iterator over the access needed by
QueryData::fetch. Access conflicts are usually
checked in WorldQuery::update_component_access, but in certain cases this method can be useful to implement
a way of checking for access conflicts in a non-allocating way.fn provide_extra_access(
_state: &mut Self::State,
_access: &mut Access,
_available_access: &Access,
)
fn provide_extra_access( _state: &mut Self::State, _access: &mut Access, _available_access: &Access, )
Offers additional access above what we requested in
update_component_access.
Implementations may add additional access that is a subset of available_access
and does not conflict with anything in access,
and must update access to include that access. Read moreimpl<T> ReleaseStateQueryData for Has<T>where
T: Component,
impl<T> ReleaseStateQueryData for Has<T>where
T: Component,
impl<T> WorldQuery for Has<T>where
T: Component,
impl<T> WorldQuery for Has<T>where
T: Component,
const IS_DENSE: bool
const IS_DENSE: bool
Returns true if (and only if) every table of every archetype matched by this fetch contains
all of the matched components. Read more
type Fetch<'w> = bool
type Fetch<'w> = bool
Per archetype/table state retrieved by this
WorldQuery to compute Self::Item for each entity.type State = ComponentId
type State = ComponentId
State used to construct a
Self::Fetch. This will be cached inside QueryState,
so it is best to move as much data / computation here as possible to reduce the cost of
constructing Self::Fetch.fn shrink_fetch<'wlong, 'wshort>(
fetch: <Has<T> as WorldQuery>::Fetch<'wlong>,
) -> <Has<T> as WorldQuery>::Fetch<'wshort>where
'wlong: 'wshort,
fn shrink_fetch<'wlong, 'wshort>(
fetch: <Has<T> as WorldQuery>::Fetch<'wlong>,
) -> <Has<T> as WorldQuery>::Fetch<'wshort>where
'wlong: 'wshort,
This function manually implements subtyping for the query fetches.
unsafe fn init_fetch<'w, 's>(
_world: UnsafeWorldCell<'w>,
_state: &'s <Has<T> as WorldQuery>::State,
_last_run: Tick,
_this_run: Tick,
) -> <Has<T> as WorldQuery>::Fetch<'w>
unsafe fn init_fetch<'w, 's>( _world: UnsafeWorldCell<'w>, _state: &'s <Has<T> as WorldQuery>::State, _last_run: Tick, _this_run: Tick, ) -> <Has<T> as WorldQuery>::Fetch<'w>
Creates a new instance of
Self::Fetch,
by combining data from the World with the cached Self::State.
Readonly accesses resources registered in WorldQuery::update_component_access. Read moreunsafe fn set_archetype<'w, 's>(
fetch: &mut <Has<T> as WorldQuery>::Fetch<'w>,
state: &'s <Has<T> as WorldQuery>::State,
archetype: &'w Archetype,
_table: &Table,
)
unsafe fn set_archetype<'w, 's>( fetch: &mut <Has<T> as WorldQuery>::Fetch<'w>, state: &'s <Has<T> as WorldQuery>::State, archetype: &'w Archetype, _table: &Table, )
Adjusts internal state to account for the next
Archetype. This will always be called on
archetypes that match this WorldQuery. Read moreunsafe fn set_table<'w, 's>(
fetch: &mut <Has<T> as WorldQuery>::Fetch<'w>,
state: &'s <Has<T> as WorldQuery>::State,
table: &'w Table,
)
unsafe fn set_table<'w, 's>( fetch: &mut <Has<T> as WorldQuery>::Fetch<'w>, state: &'s <Has<T> as WorldQuery>::State, table: &'w Table, )
Adjusts internal state to account for the next
Table. This will always be called on tables
that match this WorldQuery. Read morefn update_component_access(
_: &<Has<T> as WorldQuery>::State,
access: &mut FilteredAccess,
)
fn update_component_access( _: &<Has<T> as WorldQuery>::State, access: &mut FilteredAccess, )
fn init_state(world: &mut World) -> ComponentId
fn init_state(world: &mut World) -> ComponentId
Creates and initializes a
State for this WorldQuery type.fn get_state(components: &Components) -> Option<<Has<T> as WorldQuery>::State>
fn get_state(components: &Components) -> Option<<Has<T> as WorldQuery>::State>
fn matches_component_set(
_state: &<Has<T> as WorldQuery>::State,
_set_contains_id: &impl Fn(ComponentId) -> bool,
) -> bool
fn matches_component_set( _state: &<Has<T> as WorldQuery>::State, _set_contains_id: &impl Fn(ComponentId) -> bool, ) -> bool
fn init_nested_access(
_state: &Self::State,
_system_name: Option<&str>,
_component_access_set: &mut FilteredAccessSet,
_world: UnsafeWorldCell<'_>,
)
fn init_nested_access( _state: &Self::State, _system_name: Option<&str>, _component_access_set: &mut FilteredAccessSet, _world: UnsafeWorldCell<'_>, )
Adds any component accesses to other entities used by this
WorldQuery. Read morefn update_archetypes(_state: &mut Self::State, _world: UnsafeWorldCell<'_>)
fn update_archetypes(_state: &mut Self::State, _world: UnsafeWorldCell<'_>)
Called when the query state is updating its archetype cache.
This can be used by nested queries to update their internal archetype caches.
impl<T> ArchetypeQueryData for Has<T>where
T: Component,
impl<T> IterQueryData for Has<T>where
T: Component,
impl<T> ReadOnlyQueryData for Has<T>where
T: Component,
impl<T> SingleEntityQueryData for Has<T>where
T: Component,