Struct SpawnDetails
pub struct SpawnDetails { /* private fields */ }Expand description
The SpawnDetails query parameter fetches the Tick the entity was spawned at.
To evaluate whether the spawn happened since the last time the system ran, the system
param SystemChangeTick needs to be used.
If the query should filter for spawned entities instead, use the
Spawned query filter instead.
Examples
fn print_spawn_details(query: Query<(Entity, SpawnDetails)>) {
for (entity, spawn_details) in &query {
if spawn_details.is_spawned() {
print!("new ");
}
print!(
"entity {:?} spawned at {:?}",
entity,
spawn_details.spawn_tick()
);
match spawn_details.spawned_by().into_option() {
Some(location) => println!(" by {:?}", location),
None => println!()
}
}
}
Implementations
impl SpawnDetails
impl SpawnDetails
pub fn is_spawned(self) -> bool
pub fn is_spawned(self) -> bool
Returns true if the entity spawned since the last time this system ran.
Otherwise, returns false.
pub fn is_spawned_after(self, other: Tick) -> bool
pub fn is_spawned_after(self, other: Tick) -> bool
Returns true if the entity spawned after the other tick.
Otherwise, returns false.
pub fn spawn_tick(self) -> Tick
pub fn spawn_tick(self) -> Tick
Returns the Tick this entity spawned at.
pub fn spawned_by(self) -> MaybeLocation
pub fn spawned_by(self) -> MaybeLocation
Returns the source code location from which this entity has been spawned.