Spawned

Struct Spawned 

pub struct Spawned;
A filter that only retains results the first time after the entity has been spawned.

A common use for this filter is one-time initialization.

To retain all results without filtering but still check whether they were spawned after the system last ran, use SpawnDetails instead.

Note that this includes entities that spawned before the first time this Query was run.

Deferred

Note, that entity spawns issued with Commands are visible only after deferred operations are applied, typically after the system that queued them.

Time complexity

Spawned is not ArchetypeFilter, which practically means that if query matches million entities, Spawned filter will iterate over all of them even if none of them were spawned.

For example, these two systems are roughly equivalent in terms of performance:


fn system1(query: Query<Entity, Spawned>) {
    for entity in &query { /* entity spawned */ }
}

fn system2(query: Query<(Entity, SpawnDetails)>) {
    for (entity, spawned) in &query {
        if spawned.is_spawned() { /* entity spawned */ }
    }
}

Examples


fn print_spawning_entities(query: Query<&Name, Spawned>) {
    for name in &query {
        println!("Entity spawned: {:?}", name);
    }
}