ReleaseStateQueryData

Trait ReleaseStateQueryData 

pub trait ReleaseStateQueryData: QueryData {
    // Required method
    fn release_state<'w>(item: Self::Item<'w, '_>) -> Self::Item<'w, 'static>;
}
A QueryData that does not borrow from its QueryState.

This is implemented by most QueryData types. The main exceptions are FilteredEntityRef, FilteredEntityMut, EntityRefExcept, and EntityMutExcept, which borrow an access list from their query state. Consider using a full EntityRef or EntityMut if you would need those.

Required Methods

fn release_state<'w>(item: Self::Item<'w, '_>) -> Self::Item<'w, 'static>

Releases the borrow from the query state by converting an item to have a 'static state lifetime.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types



impl ReleaseStateQueryData for ()



fn release_state<'w>( _: <() as QueryData>::Item<'w, '_>, ) -> <() as QueryData>::Item<'w, 'static>



impl<F0, F1> ReleaseStateQueryData for (F0, F1)



fn release_state<'w>( _: <(F0, F1) as QueryData>::Item<'w, '_>, ) -> <(F0, F1) as QueryData>::Item<'w, 'static>



impl<F0, F1, F2> ReleaseStateQueryData for (F0, F1, F2)



fn release_state<'w>( _: <(F0, F1, F2) as QueryData>::Item<'w, '_>, ) -> <(F0, F1, F2) as QueryData>::Item<'w, 'static>



impl<F0, F1, F2, F3> ReleaseStateQueryData for (F0, F1, F2, F3)



fn release_state<'w>( _: <(F0, F1, F2, F3) as QueryData>::Item<'w, '_>, ) -> <(F0, F1, F2, F3) as QueryData>::Item<'w, 'static>



impl<F0, F1, F2, F3, F4> ReleaseStateQueryData for (F0, F1, F2, F3, F4)



fn release_state<'w>( _: <(F0, F1, F2, F3, F4) as QueryData>::Item<'w, '_>, ) -> <(F0, F1, F2, F3, F4) as QueryData>::Item<'w, 'static>



impl<F0, F1, F2, F3, F4, F5> ReleaseStateQueryData for (F0, F1, F2, F3, F4, F5)



impl<F0, F1, F2, F3, F4, F5, F6> ReleaseStateQueryData for (F0, F1, F2, F3, F4, F5, F6)



impl<F0, F1, F2, F3, F4, F5, F6, F7> ReleaseStateQueryData for (F0, F1, F2, F3, F4, F5, F6, F7)



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8> ReleaseStateQueryData for (F0, F1, F2, F3, F4, F5, F6, F7, F8)



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8, F9> ReleaseStateQueryData for (F0, F1, F2, F3, F4, F5, F6, F7, F8, F9)



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10> ReleaseStateQueryData for (F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10)



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11> ReleaseStateQueryData for (F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11)



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12> ReleaseStateQueryData for (F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12)



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, F13> ReleaseStateQueryData for (F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, F13)



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, F13, F14> ReleaseStateQueryData for (F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, F13, F14)



impl<F> ReleaseStateQueryData for (F,)



fn release_state<'w>( _: <(F,) as QueryData>::Item<'w, '_>, ) -> <(F,) as QueryData>::Item<'w, 'static>



impl<T> ReleaseStateQueryData for Option<T>



fn release_state<'w>( item: <Option<T> as QueryData>::Item<'w, '_>, ) -> <Option<T> as QueryData>::Item<'w, 'static>



impl<T> ReleaseStateQueryData for &T
where T: Component,



fn release_state<'w>( item: <&T as QueryData>::Item<'w, '_>, ) -> <&T as QueryData>::Item<'w, 'static>



impl<T> ReleaseStateQueryData for &mut T
where T: Component<Mutability = Mutable>,



fn release_state<'w>( item: <&mut T as QueryData>::Item<'w, '_>, ) -> <&mut T as QueryData>::Item<'w, 'static>



impl<T> ReleaseStateQueryData for PhantomData<T>
where T: ?Sized,



fn release_state<'w>( _item: <PhantomData<T> as QueryData>::Item<'w, '_>, ) -> <PhantomData<T> as QueryData>::Item<'w, 'static>

Implementors



impl ReleaseStateQueryData for &Archetype

Source

impl ReleaseStateQueryData for EntityInitQuery
where &'static EntityId: for<'__a> ReleaseStateQueryData, &'static UniqueId: for<'__a> ReleaseStateQueryData, &'static EntityKind: for<'__a> ReleaseStateQueryData, &'static Look: for<'__a> ReleaseStateQueryData, &'static HeadYaw: for<'__a> ReleaseStateQueryData, &'static OnGround: for<'__a> ReleaseStateQueryData, &'static ObjectData: for<'__a> ReleaseStateQueryData, &'static Velocity: for<'__a> ReleaseStateQueryData, &'static TrackedData: for<'__a> ReleaseStateQueryData,

Source

impl ReleaseStateQueryData for UpdateEntityQuery
where &'static EntityId: for<'__a> ReleaseStateQueryData, &'static Position: for<'__a> ReleaseStateQueryData, &'static OldPosition: for<'__a> ReleaseStateQueryData, &'static EntityLayerId: for<'__a> ReleaseStateQueryData, &'static OldEntityLayerId: for<'__a> ReleaseStateQueryData, Ref<'static, Look>: for<'__a> ReleaseStateQueryData, Ref<'static, HeadYaw>: for<'__a> ReleaseStateQueryData, &'static OnGround: for<'__a> ReleaseStateQueryData, Ref<'static, Velocity>: for<'__a> ReleaseStateQueryData, &'static TrackedData: for<'__a> ReleaseStateQueryData, &'static EntityStatuses: for<'__a> ReleaseStateQueryData, &'static EntityAnimations: for<'__a> ReleaseStateQueryData, Option<&'static TrackedEntityAttributes>: for<'__a> ReleaseStateQueryData,



impl ReleaseStateQueryData for AnyOf<()>

Source

impl ReleaseStateQueryData for ClientSpawnQuery
where &'static mut IsHardcore: for<'__a> ReleaseStateQueryData, &'static mut GameMode: for<'__a> ReleaseStateQueryData, &'static mut PrevGameMode: for<'__a> ReleaseStateQueryData, &'static mut HashedSeed: for<'__a> ReleaseStateQueryData, &'static mut ViewDistance: for<'__a> ReleaseStateQueryData, &'static mut ReducedDebugInfo: for<'__a> ReleaseStateQueryData, &'static mut HasRespawnScreen: for<'__a> ReleaseStateQueryData, &'static mut IsDebug: for<'__a> ReleaseStateQueryData, &'static mut IsFlat: for<'__a> ReleaseStateQueryData, &'static mut DeathLocation: for<'__a> ReleaseStateQueryData, &'static mut PortalCooldown: for<'__a> ReleaseStateQueryData,

Source

impl ReleaseStateQueryData for ClientSpawnQueryReadOnly
where &'static mut IsHardcore: for<'__a> QueryData, <&'static mut IsHardcore as QueryData>::ReadOnly: for<'__a> ReleaseStateQueryData, &'static mut GameMode: for<'__a> QueryData, <&'static mut GameMode as QueryData>::ReadOnly: for<'__a> ReleaseStateQueryData, &'static mut PrevGameMode: for<'__a> QueryData, <&'static mut PrevGameMode as QueryData>::ReadOnly: for<'__a> ReleaseStateQueryData, &'static mut HashedSeed: for<'__a> QueryData, <&'static mut HashedSeed as QueryData>::ReadOnly: for<'__a> ReleaseStateQueryData, &'static mut ViewDistance: for<'__a> QueryData, <&'static mut ViewDistance as QueryData>::ReadOnly: for<'__a> ReleaseStateQueryData, &'static mut ReducedDebugInfo: for<'__a> QueryData, <&'static mut ReducedDebugInfo as QueryData>::ReadOnly: for<'__a> ReleaseStateQueryData, &'static mut HasRespawnScreen: for<'__a> QueryData, <&'static mut HasRespawnScreen as QueryData>::ReadOnly: for<'__a> ReleaseStateQueryData, &'static mut IsDebug: for<'__a> QueryData, <&'static mut IsDebug as QueryData>::ReadOnly: for<'__a> ReleaseStateQueryData, &'static mut IsFlat: for<'__a> QueryData, <&'static mut IsFlat as QueryData>::ReadOnly: for<'__a> ReleaseStateQueryData, &'static mut DeathLocation: for<'__a> QueryData, <&'static mut DeathLocation as QueryData>::ReadOnly: for<'__a> ReleaseStateQueryData, &'static mut PortalCooldown: for<'__a> QueryData, <&'static mut PortalCooldown as QueryData>::ReadOnly: for<'__a> ReleaseStateQueryData,



impl ReleaseStateQueryData for Entity



impl ReleaseStateQueryData for EntityMut<'_>



impl ReleaseStateQueryData for EntityRef<'_>



impl ReleaseStateQueryData for NameOrEntity
where Option<&'static Name>: for<'__a> ReleaseStateQueryData, Entity: for<'__a> ReleaseStateQueryData,

Source

impl ReleaseStateQueryData for OldView
where &'static OldPosition: for<'__a> ReleaseStateQueryData, &'static OldViewDistance: for<'__a> ReleaseStateQueryData,

Source

impl ReleaseStateQueryData for View
where &'static Position: for<'__a> ReleaseStateQueryData, &'static ViewDistance: for<'__a> ReleaseStateQueryData,



impl ReleaseStateQueryData for EntityLocation



impl ReleaseStateQueryData for SpawnDetails



impl<F0, F1> ReleaseStateQueryData for AnyOf<(F0, F1)>



impl<F0, F1, F2> ReleaseStateQueryData for AnyOf<(F0, F1, F2)>



impl<F0, F1, F2, F3> ReleaseStateQueryData for AnyOf<(F0, F1, F2, F3)>



impl<F0, F1, F2, F3, F4> ReleaseStateQueryData for AnyOf<(F0, F1, F2, F3, F4)>



impl<F0, F1, F2, F3, F4, F5> ReleaseStateQueryData for AnyOf<(F0, F1, F2, F3, F4, F5)>



impl<F0, F1, F2, F3, F4, F5, F6> ReleaseStateQueryData for AnyOf<(F0, F1, F2, F3, F4, F5, F6)>



impl<F0, F1, F2, F3, F4, F5, F6, F7> ReleaseStateQueryData for AnyOf<(F0, F1, F2, F3, F4, F5, F6, F7)>



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8> ReleaseStateQueryData for AnyOf<(F0, F1, F2, F3, F4, F5, F6, F7, F8)>



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8, F9> ReleaseStateQueryData for AnyOf<(F0, F1, F2, F3, F4, F5, F6, F7, F8, F9)>



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10> ReleaseStateQueryData for AnyOf<(F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10)>



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11> ReleaseStateQueryData for AnyOf<(F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11)>



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12> ReleaseStateQueryData for AnyOf<(F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12)>



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, F13> ReleaseStateQueryData for AnyOf<(F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, F13)>



impl<F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, F13, F14> ReleaseStateQueryData for AnyOf<(F0, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, F13, F14)>



impl<F> ReleaseStateQueryData for AnyOf<(F,)>



impl<T> ReleaseStateQueryData for Has<T>
where T: Component,



impl<T> ReleaseStateQueryData for Mut<'_, T>
where T: Component<Mutability = Mutable>,



impl<T> ReleaseStateQueryData for Ref<'_, T>
where T: Component,