Struct FilteredAccess
pub struct FilteredAccess<T>where
T: SparseSetIndex,{ /* private fields */ }Expand description
An Access that has been filtered to include and exclude certain combinations of elements.
Used internally to statically check if queries are disjoint.
Subtle: a read or write in access should not be considered to imply a
with access.
For example consider Query<Option<&T>> this only has a read of T as doing
otherwise would allow for queries to be considered disjoint when they shouldn’t:
Query<(&mut T, Option<&U>)>read/writeT, readU, withUQuery<&mut T, Without<U>>read/writeT, withoutUfrom this we could reasonably conclude that the queries are disjoint but they aren’t.
In order to solve this the actual access that Query<(&mut T, Option<&U>)> has
is read/write T, read U. It must still have a read U access otherwise the following
queries would be incorrectly considered disjoint:
Query<&mut T>read/writeTQuery<Option<&T>>accesses nothing
See comments the WorldQuery impls of AnyOf/Option/Or for more information.
Implementations
impl<T> FilteredAccess<T>where
T: SparseSetIndex,
impl<T> FilteredAccess<T>where
T: SparseSetIndex,
pub fn access_mut(&mut self) -> &mut Access<T>
pub fn access_mut(&mut self) -> &mut Access<T>
Returns a mutable reference to the underlying unfiltered access.
pub fn add_read(&mut self, index: T)
pub fn add_read(&mut self, index: T)
Adds access to the element given by index.
pub fn add_write(&mut self, index: T)
pub fn add_write(&mut self, index: T)
Adds exclusive access to the element given by index.
pub fn and_with(&mut self, index: T)
pub fn and_with(&mut self, index: T)
Adds a With filter: corresponds to a conjunction (AND) operation.
Suppose we begin with Or<(With<A>, With<B>)>, which is represented by an array of two AccessFilter instances.
Adding AND With<C> via this method transforms it into the equivalent of Or<((With<A>, With<C>), (With<B>, With<C>))>.
pub fn and_without(&mut self, index: T)
pub fn and_without(&mut self, index: T)
Adds a Without filter: corresponds to a conjunction (AND) operation.
Suppose we begin with Or<(With<A>, With<B>)>, which is represented by an array of two AccessFilter instances.
Adding AND Without<C> via this method transforms it into the equivalent of Or<((With<A>, Without<C>), (With<B>, Without<C>))>.
pub fn append_or(&mut self, other: &FilteredAccess<T>)
pub fn append_or(&mut self, other: &FilteredAccess<T>)
Appends an array of filters: corresponds to a disjunction (OR) operation.
As the underlying array of filters represents a disjunction,
where each element (AccessFilters) represents a conjunction,
we can simply append to the array.
pub fn extend_access(&mut self, other: &FilteredAccess<T>)
pub fn extend_access(&mut self, other: &FilteredAccess<T>)
Adds all of the accesses from other to self.
pub fn is_compatible(&self, other: &FilteredAccess<T>) -> bool
pub fn is_compatible(&self, other: &FilteredAccess<T>) -> bool
Returns true if this and other can be active at the same time.
pub fn get_conflicts(&self, other: &FilteredAccess<T>) -> Vec<T>
pub fn get_conflicts(&self, other: &FilteredAccess<T>) -> Vec<T>
Returns a vector of elements that this and other cannot access at the same time.
pub fn extend(&mut self, other: &FilteredAccess<T>)
pub fn extend(&mut self, other: &FilteredAccess<T>)
Adds all access and filters from other.
Corresponds to a conjunction operation (AND) for filters.
Extending Or<(With<A>, Without<B>)> with Or<(With<C>, Without<D>)> will result in
Or<((With<A>, With<C>), (With<A>, Without<D>), (Without<B>, With<C>), (Without<B>, Without<D>))>.
pub fn read_all(&mut self)
pub fn read_all(&mut self)
Sets the underlying unfiltered access as having access to all indexed elements.
pub fn write_all(&mut self)
pub fn write_all(&mut self)
Sets the underlying unfiltered access as having mutable access to all indexed elements.
pub fn is_subset(&self, other: &FilteredAccess<T>) -> bool
pub fn is_subset(&self, other: &FilteredAccess<T>) -> bool
Returns true if the set is a subset of another, i.e. other contains
at least all the values in self.
pub fn with_filters(&self) -> impl Iterator<Item = T>
pub fn with_filters(&self) -> impl Iterator<Item = T>
Returns the indices of the elements that this access filters for.
pub fn without_filters(&self) -> impl Iterator<Item = T>
pub fn without_filters(&self) -> impl Iterator<Item = T>
Returns the indices of the elements that this access filters out.