Struct FilteredAccessSet
pub struct FilteredAccessSet { /* private fields */ }Expand description
A collection of FilteredAccess instances.
Used internally to statically check if systems have conflicting access.
It stores multiple sets of accesses.
- A “combined” set, which is the access of all filters in this set combined.
- The set of access of each individual filters in this set.
Implementations
impl FilteredAccessSet
impl FilteredAccessSet
pub const fn new() -> FilteredAccessSet
pub const fn new() -> FilteredAccessSet
Creates an empty FilteredAccessSet.
pub fn combined_access(&self) -> &Access
pub fn combined_access(&self) -> &Access
Returns a reference to the unfiltered access of the entire set.
pub fn filtered_accesses(&self) -> &[FilteredAccess]
pub fn filtered_accesses(&self) -> &[FilteredAccess]
Returns a reference to the filtered accesses of the set.
pub fn is_compatible(&self, other: &FilteredAccessSet) -> bool
pub fn is_compatible(&self, other: &FilteredAccessSet) -> bool
Returns true if this and other can be active at the same time.
Access conflict resolution happen in two steps:
- A “coarse” check, if there is no mutual unfiltered conflict between
selfandother, we already know that the two access sets are compatible. - A “fine grained” check, it kicks in when the “coarse” check fails.
the two access sets might still be compatible if some of the accesses
are restricted with the
WithorWithoutfilters so that access is mutually exclusive. The fine grained phase iterates over all filters in theselfset and compares it to all the filters in theotherset, making sure they are all mutually compatible.
pub fn get_conflicts(&self, other: &FilteredAccessSet) -> AccessConflicts
pub fn get_conflicts(&self, other: &FilteredAccessSet) -> AccessConflicts
Returns a vector of elements that this set and other cannot access at the same time.
pub fn get_conflicts_single(
&self,
filtered_access: &FilteredAccess,
) -> AccessConflicts
pub fn get_conflicts_single( &self, filtered_access: &FilteredAccess, ) -> AccessConflicts
Returns a vector of elements that this set and other cannot access at the same time.
pub fn add(&mut self, filtered_access: FilteredAccess)
pub fn add(&mut self, filtered_access: FilteredAccess)
Adds the filtered access to the set.
pub fn add_unfiltered_resource_read(&mut self, index: ComponentId)
👎Deprecated since 0.19.0: FilteredAccessSet::add_resource_read
pub fn add_unfiltered_resource_read(&mut self, index: ComponentId)
FilteredAccessSet::add_resource_read
Adds a read access to a resource to the set.
pub fn add_resource_read(&mut self, index: ComponentId)
pub fn add_resource_read(&mut self, index: ComponentId)
Adds a read access to a resource to the set.
pub fn add_unfiltered_read_all_components(&mut self)
pub fn add_unfiltered_read_all_components(&mut self)
Adds read access to all components to the set.
pub fn add_unfiltered_resource_write(&mut self, index: ComponentId)
👎Deprecated since 0.19.0: FilteredAccessSet::add_resource_write
pub fn add_unfiltered_resource_write(&mut self, index: ComponentId)
FilteredAccessSet::add_resource_write
Adds a write access to a resource to the set.
pub fn add_resource_write(&mut self, index: ComponentId)
pub fn add_resource_write(&mut self, index: ComponentId)
Adds a write access to a resource to the set.
pub fn add_unfiltered_write_all_components(&mut self)
pub fn add_unfiltered_write_all_components(&mut self)
Adds write access to all components to the set.
pub fn extend(&mut self, filtered_access_set: FilteredAccessSet)
pub fn extend(&mut self, filtered_access_set: FilteredAccessSet)
Adds all of the accesses from the passed set to self.
pub fn read_all(&mut self)
pub fn read_all(&mut self)
Marks the set as reading all possible indices of type T.
pub fn write_all(&mut self)
pub fn write_all(&mut self)
Marks the set as writing all T.
pub fn clear(&mut self)
pub fn clear(&mut self)
Removes all accesses stored in this set.